=== modified file 'drizzled/db.cc'
--- drizzled/db.cc	2010-02-13 23:50:31 +0000
+++ drizzled/db.cc	2010-02-16 01:41:20 +0000
@@ -288,7 +288,7 @@
   else if (error_erno)
     error= true;
 
-  replication_services.rawStatement(session, session->query, session->query_length);
+  replication_services.rawStatement(session, session->query);
   session->my_ok(result);
 
 exit:
@@ -342,7 +342,7 @@
     goto exit;
   }
 
-  replication_services.rawStatement(session, session->getQueryString(), session->getQueryLength());
+  replication_services.rawStatement(session, session->getQueryString());
   session->my_ok(result);
 
   pthread_mutex_unlock(&LOCK_create_db);
@@ -441,16 +441,10 @@
   }
   if (deleted >= 0)
   {
-    const char *query;
-    uint32_t query_length;
-
-    assert(session->query);
-
-    query= session->query;
-    query_length= session->query_length;
+    assert(! session->query.empty());
 
     ReplicationServices &replication_services= ReplicationServices::singleton();
-    replication_services.rawStatement(session, session->getQueryString(), session->getQueryLength());
+    replication_services.rawStatement(session, session->getQueryString());
     session->clear_error();
     session->server_status|= SERVER_STATUS_DB_DROPPED;
     session->my_ok((uint32_t) deleted);
@@ -478,7 +472,7 @@
       if (query_pos + tbl_name_len + 1 >= query_end)
       {
         /* These DDL methods and logging protected with LOCK_create_db */
-        replication_services.rawStatement(session, query, (size_t) (query_pos -1 - query));
+        replication_services.rawStatement(session, query);
         query_pos= query_data_start;
       }
 
@@ -491,7 +485,7 @@
     if (query_pos != query_data_start)
     {
       /* These DDL methods and logging protected with LOCK_create_db */
-      replication_services.rawStatement(session, query, (size_t) (query_pos -1 - query));
+      replication_services.rawStatement(session, query);
     }
   }
 

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2010-02-13 23:50:31 +0000
+++ drizzled/drizzled.cc	2010-02-16 01:41:20 +0000
@@ -840,7 +840,7 @@
     fprintf(stderr, _("Trying to get some variables.\n"
                       "Some pointers may be invalid and cause the "
                       "dump to abort...\n"));
-    safe_print_str("session->query", session->query, 1024);
+    safe_print_str("session->query", session->query.c_str(), 1024);
     fprintf(stderr, "session->thread_id=%"PRIu32"\n", (uint32_t) session->thread_id);
     fprintf(stderr, "session->killed=%s\n", kreason);
   }

=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2010-02-05 04:05:31 +0000
+++ drizzled/join.cc	2010-02-11 20:01:37 +0000
@@ -5995,7 +5995,7 @@
   if (join->const_tables != join->tables)
   {
     optimize_keyuse(join, keyuse_array);
-    DRIZZLE_QUERY_OPT_CHOOSE_PLAN_START(join->session->query, join->session->thread_id);
+    DRIZZLE_QUERY_OPT_CHOOSE_PLAN_START(join->session->query.c_str(), join->session->thread_id);
     bool res= choose_plan(join, all_table_map & ~join->const_table_map);
     DRIZZLE_QUERY_OPT_CHOOSE_PLAN_DONE(res ? 1 : 0);
     if (res)

=== modified file 'drizzled/lex_input_stream.h'
--- drizzled/lex_input_stream.h	2010-02-04 08:14:46 +0000
+++ drizzled/lex_input_stream.h	2010-02-11 16:22:34 +0000
@@ -358,12 +358,6 @@
   /** Current state of the lexical analyser. */
   enum my_lex_states next_state;
 
-  /**
-    Position of ';' in the stream, to delimit multiple queries.
-    This delimiter is in the raw buffer.
-  */
-  const char *found_semicolon;
-
   /** Token character bitmaps, to detect 7bit strings. */
   unsigned char tok_bitmap;
 

=== modified file 'drizzled/plugin.h'
--- drizzled/plugin.h	2010-02-05 20:19:10 +0000
+++ drizzled/plugin.h	2010-02-11 03:49:10 +0000
@@ -435,7 +435,6 @@
 unsigned long session_get_thread_id(const Session *session);
 
 const charset_info_st *session_charset(Session *session);
-char **session_query(Session *session);
 int session_non_transactional_update(const Session *session);
 void session_mark_transaction_to_rollback(Session *session, bool all);
 

=== modified file 'drizzled/replication_services.cc'
--- drizzled/replication_services.cc	2010-02-08 01:10:03 +0000
+++ drizzled/replication_services.cc	2010-02-11 03:49:10 +0000
@@ -759,7 +759,7 @@
   cleanupTransaction(transaction, in_session);
 }
 
-void ReplicationServices::rawStatement(Session *in_session, const char *in_query, size_t in_query_len)
+void ReplicationServices::rawStatement(Session *in_session, const string &query)
 {
   if (! is_active)
     return;
@@ -768,7 +768,6 @@
   message::Statement *statement= transaction->add_statement();
 
   initStatement(*statement, message::Statement::RAW_SQL, in_session);
-  string query(in_query, in_query_len);
   statement->set_sql(query);
   finalizeStatement(*statement, in_session);
 

=== modified file 'drizzled/replication_services.h'
--- drizzled/replication_services.h	2010-02-04 08:14:46 +0000
+++ drizzled/replication_services.h	2010-02-11 03:29:52 +0000
@@ -342,9 +342,8 @@
    *
    * @param Pointer to the Session which issued the statement
    * @param Query string
-   * @param Length of the query string
    */
-  void rawStatement(Session *in_session, const char *in_query, size_t in_query_len);
+  void rawStatement(Session *in_session, const std::string &query);
   /**
    * Returns the timestamp of the last Transaction which was sent to 
    * an applier.

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2010-02-13 23:50:31 +0000
+++ drizzled/session.cc	2010-02-16 01:41:20 +0000
@@ -177,6 +177,7 @@
   Open_tables_state(refresh_version),
   mem_root(&main_mem_root),
   lex(&main_lex),
+  query(),
   client(client_arg),
   scheduler(NULL),
   scheduler_arg(NULL),
@@ -227,8 +228,6 @@
   thread_id= 0;
   file_id = 0;
   query_id= 0;
-  query= NULL;
-  query_length= 0;
   warn_query_id= 0;
   memset(ha_data, 0, sizeof(ha_data));
   mysys_var= 0;
@@ -755,14 +754,7 @@
     in_packet_length--;
   }
 
-  /* We must allocate some extra memory for the cached query string */
-  query_length= 0; /* Extra safety: Avoid races */
-  query= (char*) memdup_w_gap((unsigned char*) in_packet, in_packet_length, db.length() + 1);
-  if (! query)
-    return false;
-
-  query[in_packet_length]=0;
-  query_length= in_packet_length;
+  query.assign(in_packet, in_packet + in_packet_length);
 
   return true;
 }
@@ -1688,11 +1680,6 @@
   return(session->charset());
 }
 
-char **session_query(Session *session)
-{
-  return(&session->query);
-}
-
 int session_non_transactional_update(const Session *session)
 {
   return(session->transaction.all.modified_non_trans_table);

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2010-02-11 21:53:40 +0000
+++ drizzled/session.h	2010-02-16 01:41:20 +0000
@@ -407,30 +407,8 @@
    */
   uint32_t id;
   LEX *lex; /**< parse tree descriptor */
-  /**
-    Points to the query associated with this statement. It's const, but
-    we need to declare it char * because all table handlers are written
-    in C and need to point to it.
-
-    Note that (A) if we set query = NULL, we must at the same time set
-    query_length = 0, and protect the whole operation with the
-    LOCK_thread_count mutex. And (B) we are ONLY allowed to set query to a
-    non-NULL value if its previous value is NULL. We do not need to protect
-    operation (B) with any mutex. To avoid crashes in races, if we do not
-    know that session->query cannot change at the moment, one should print
-    session->query like this:
-      (1) reserve the LOCK_thread_count mutex;
-      (2) check if session->query is NULL;
-      (3) if not NULL, then print at most session->query_length characters from
-      it. We will see the query_length field as either 0, or the right value
-      for it.
-    Assuming that the write and read of an n-bit memory field in an n-bit
-    computer is atomic, we can avoid races in the above way.
-    This printing is needed at least in SHOW PROCESSLIST and SHOW INNODB
-    STATUS.
-  */
-  char *query;
-  uint32_t query_length; /**< current query length */
+  /** query associated with this statement */
+  std::string query;
 
   /**
     Name of the current (default) database.
@@ -800,7 +778,7 @@
   }
 
   /** Returns the current query text */
-  inline const char *getQueryString()  const
+  inline const std::string &getQueryString()  const
   {
     return query;
   }
@@ -808,8 +786,8 @@
   /** Returns the length of the current query text */
   inline size_t getQueryLength() const
   {
-    if (query != NULL)
-      return strlen(query);
+    if (! query.empty())
+      return query.length();
     else
       return 0;
   }

=== modified file 'drizzled/sql_lex.cc'
--- drizzled/sql_lex.cc	2010-02-04 08:14:46 +0000
+++ drizzled/sql_lex.cc	2010-02-11 16:22:34 +0000
@@ -84,7 +84,6 @@
   m_body_utf8(NULL),
   m_cpp_utf8_processed_ptr(NULL),
   next_state(MY_LEX_START),
-  found_semicolon(NULL),
   ignore_space(1),
   in_comment(NO_COMMENT)
 {

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2010-02-13 23:50:31 +0000
+++ drizzled/sql_parse.cc	2010-02-16 01:55:51 +0000
@@ -65,8 +65,7 @@
 /* Prototypes */
 bool my_yyoverflow(short **a, YYSTYPE **b, ulong *yystacksize);
 static bool parse_sql(Session *session, Lex_input_stream *lip);
-void mysql_parse(Session *session, const char *inBuf, uint32_t length,
-                 const char ** found_semicolon);
+void mysql_parse(Session *session, const char *inBuf, uint32_t length);
 
 /**
   @defgroup Runtime_Environment Runtime Environment
@@ -220,12 +219,11 @@
   {
     if (! session->readAndStoreQuery(packet, packet_length))
       break;					// fatal error is set
-    DRIZZLE_QUERY_START(session->query,
+    DRIZZLE_QUERY_START(session->query.c_str(),
                         session->thread_id,
                         const_cast<const char *>(session->db.empty() ? "" : session->db.c_str()));
-    const char* end_of_stmt= NULL;
 
-    mysql_parse(session, session->query, session->query_length, &end_of_stmt);
+    mysql_parse(session, session->query.c_str(), session->query.length());
 
     break;
   }
@@ -316,8 +314,7 @@
   session->set_proc_info("cleaning up");
   session->command= COM_SLEEP;
   memset(session->process_list_info, 0, PROCESS_LIST_WIDTH);
-  session->query= 0;
-  session->query_length= 0;
+  session->query.clear();
 
   session->set_proc_info(NULL);
   free_root(session->mem_root,MYF(memory::KEEP_PREALLOC));
@@ -471,10 +468,10 @@
   /* list of all tables in query */
   TableList *all_tables;
   /* A peek into the query string */
-  size_t proc_info_len= session->query_length > PROCESS_LIST_WIDTH ?
-                        PROCESS_LIST_WIDTH : session->query_length;
+  size_t proc_info_len= session->query.length() > PROCESS_LIST_WIDTH ?
+                        PROCESS_LIST_WIDTH : session->query.length();
 
-  memcpy(session->process_list_info, session->query, proc_info_len);
+  memcpy(session->process_list_info, session->query.c_str(), proc_info_len);
   session->process_list_info[proc_info_len]= '\0';
 
   /*
@@ -750,76 +747,42 @@
   @param       session     Current thread
   @param       inBuf   Begining of the query text
   @param       length  Length of the query text
-  @param[out]  found_semicolon For multi queries, position of the character of
-                               the next query in the query text.
 */
 
-void mysql_parse(Session *session, const char *inBuf, uint32_t length,
-                 const char ** found_semicolon)
+void mysql_parse(Session *session, const char *inBuf, uint32_t length)
 {
-  /*
-    Warning.
-    The purpose of query_cache_send_result_to_client() is to lookup the
-    query in the query cache first, to avoid parsing and executing it.
-    So, the natural implementation would be to:
-    - first, call query_cache_send_result_to_client,
-    - second, if caching failed, initialise the lexical and syntactic parser.
-    The problem is that the query cache depends on a clean initialization
-    of (among others) lex->safe_to_cache_query and session->server_status,
-    which are reset respectively in
-    - lex_start()
-    - mysql_reset_session_for_next_command()
-    So, initializing the lexical analyser *before* using the query cache
-    is required for the cache to work properly.
-    FIXME: cleanup the dependencies in the code to simplify this.
-  */
   lex_start(session);
   session->reset_for_next_command();
 
+  LEX *lex= session->lex;
+
+  Lex_input_stream lip(session, inBuf, length);
+
+  bool err= parse_sql(session, &lip);
+
+  if (!err)
   {
-    LEX *lex= session->lex;
-
-    Lex_input_stream lip(session, inBuf, length);
-
-    bool err= parse_sql(session, &lip);
-    *found_semicolon= lip.found_semicolon;
-
-    if (!err)
     {
+      if (! session->is_error())
       {
-	if (! session->is_error())
-	{
-          /*
-            Binlog logs a string starting from session->query and having length
-            session->query_length; so we set session->query_length correctly (to not
-            log several statements in one event, when we executed only first).
-            We set it to not see the ';' (otherwise it would get into binlog
-            and Query_log_event::print() would give ';;' output).
-            This also helps display only the current query in SHOW
-            PROCESSLIST.
-            Note that we don't need LOCK_thread_count to modify query_length.
-          */
-          if (*found_semicolon &&
-              (session->query_length= (ulong)(*found_semicolon - session->query)))
-            session->query_length--;
-          DRIZZLE_QUERY_EXEC_START(session->query,
-                                   session->thread_id,
-                                   const_cast<const char *>(session->db.empty() ? "" : session->db.c_str()));
-          /* Actually execute the query */
-          mysql_execute_command(session);
-          DRIZZLE_QUERY_EXEC_DONE(0);
-	}
+        DRIZZLE_QUERY_EXEC_START(session->query.c_str(),
+                                 session->thread_id,
+                                 const_cast<const char *>(session->db.empty() ? "" : session->db.c_str()));
+        /* Actually execute the query */
+        mysql_execute_command(session);
+        DRIZZLE_QUERY_EXEC_DONE(0);
       }
     }
-    else
-    {
-      assert(session->is_error());
-    }
-    lex->unit.cleanup();
-    session->set_proc_info("freeing items");
-    session->end_statement();
-    session->cleanup_after_query();
-  }
+  }
+  else
+  {
+    assert(session->is_error());
+  }
+
+  lex->unit.cleanup();
+  session->set_proc_info("freeing items");
+  session->end_statement();
+  session->cleanup_after_query();
 
   return;
 }
@@ -1826,7 +1789,7 @@
 {
   assert(session->m_lip == NULL);
 
-  DRIZZLE_QUERY_PARSE_START(session->query);
+  DRIZZLE_QUERY_PARSE_START(session->query.c_str());
 
   /* Set Lex_input_stream. */
 

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2010-02-11 21:53:40 +0000
+++ drizzled/sql_select.cc	2010-02-16 01:41:20 +0000
@@ -116,7 +116,7 @@
 {
   bool res;
   register Select_Lex *select_lex= &lex->select_lex;
-  DRIZZLE_SELECT_START(session->query);
+  DRIZZLE_SELECT_START(session->query.c_str());
 
   if (select_lex->master_unit()->is_union() ||
       select_lex->master_unit()->fake_select_lex)

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2010-02-04 08:14:46 +0000
+++ drizzled/sql_table.cc	2010-02-11 03:29:52 +0000
@@ -342,10 +342,10 @@
 */
 
 void write_bin_log(Session *session,
-                   char const *query, size_t query_length)
+                   char const *query)
 {
   ReplicationServices &replication_services= ReplicationServices::singleton();
-  replication_services.rawStatement(session, query, query_length);
+  replication_services.rawStatement(session, query);
 }
 
 
@@ -369,7 +369,7 @@
 
   built_query.append(table_name);
   built_query.append("`");
-  replication_services.rawStatement(session, built_query.c_str(), built_query.length());
+  replication_services.rawStatement(session, built_query);
 }
 
 /*
@@ -1711,7 +1711,7 @@
     Otherwise, the statement shall be binlogged.
    */
   if (!internal_tmp_table && ! lex_identified_temp_table)
-    write_bin_log(session, session->query, session->query_length);
+    write_bin_log(session, session->query.c_str());
   error= false;
 unlock_and_end:
   pthread_mutex_unlock(&LOCK_open);
@@ -2435,10 +2435,10 @@
         int result= store_create_info(table, &query, is_if_not_exists);
 
         assert(result == 0); // store_create_info() always return 0
-        write_bin_log(session, query.ptr(), query.length());
+        write_bin_log(session, query.ptr());
       }
       else                                      // Case 1
-        write_bin_log(session, session->query, session->query_length);
+        write_bin_log(session, session->query.c_str());
     }
   }
 

=== modified file 'drizzled/sql_table.h'
--- drizzled/sql_table.h	2010-02-04 08:14:46 +0000
+++ drizzled/sql_table.h	2010-02-11 03:29:52 +0000
@@ -69,7 +69,7 @@
                           HA_CHECK_OPT* check_opt);
 
 void write_bin_log(Session *session,
-                   char const *query, size_t query_length);
+                   char const *query);
 
 bool is_primary_key(KEY *key_info);
 const char* is_primary_key_name(const char* key_name);

=== modified file 'drizzled/sql_update.cc'
--- drizzled/sql_update.cc	2010-02-05 04:05:31 +0000
+++ drizzled/sql_update.cc	2010-02-11 20:01:37 +0000
@@ -145,7 +145,7 @@
   List<Item> all_fields;
   Session::killed_state killed_status= Session::NOT_KILLED;
 
-  DRIZZLE_UPDATE_START(session->query);
+  DRIZZLE_UPDATE_START(session->query.c_str());
   if (session->openTablesLock(table_list))
   {
     DRIZZLE_UPDATE_DONE(1, 0, 0);

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2010-02-05 04:05:31 +0000
+++ drizzled/statement/alter_table.cc	2010-02-11 03:49:10 +0000
@@ -357,7 +357,7 @@
       */
       if (alter_info->build_method == HA_BUILD_ONLINE)
       {
-        my_error(ER_NOT_SUPPORTED_YET, MYF(0), session->query);
+        my_error(ER_NOT_SUPPORTED_YET, MYF(0), session->query.c_str());
         goto err;
       }
       alter_info->build_method= HA_BUILD_OFFLINE;
@@ -575,7 +575,7 @@
     error=1;
   if (error)
     goto err;
-  write_bin_log(session, session->query, session->query_length);
+  write_bin_log(session, session->query.c_str());
 
 err:
   (void) transaction_services.ha_autocommit_or_rollback(session, error);
@@ -962,7 +962,7 @@
 
     if (error == 0)
     {
-      write_bin_log(session, session->query, session->query_length);
+      write_bin_log(session, session->query.c_str());
       session->my_ok();
     }
     else if (error > 0)
@@ -1163,7 +1163,7 @@
 
   session->set_proc_info("end");
 
-  write_bin_log(session, session->query, session->query_length);
+  write_bin_log(session, session->query.c_str());
   table_list->table= NULL;
 
 end_temporary:

=== modified file 'drizzled/statement/analyze.cc'
--- drizzled/statement/analyze.cc	2009-12-21 09:40:31 +0000
+++ drizzled/statement/analyze.cc	2010-02-11 03:29:52 +0000
@@ -35,7 +35,7 @@
   Select_Lex *select_lex= &session->lex->select_lex;
   bool res= mysql_analyze_table(session, first_table, &check_opt);
   /* ! we write after unlocking the table */
-  write_bin_log(session, session->query, session->query_length);
+  write_bin_log(session, session->query.c_str());
   select_lex->table_list.first= (unsigned char*) first_table;
   session->lex->query_tables= all_tables;
   return res;

=== modified file 'drizzled/statement/delete.cc'
--- drizzled/statement/delete.cc	2009-12-21 09:40:31 +0000
+++ drizzled/statement/delete.cc	2010-02-11 20:01:37 +0000
@@ -30,7 +30,7 @@
 
 bool statement::Delete::execute()
 {
-  DRIZZLE_DELETE_START(session->query);
+  DRIZZLE_DELETE_START(session->query.c_str());
   TableList *first_table= (TableList *) session->lex->select_lex.table_list.first;
   TableList *all_tables= session->lex->query_tables;
   Select_Lex *select_lex= &session->lex->select_lex;

=== modified file 'drizzled/statement/flush.cc'
--- drizzled/statement/flush.cc	2009-12-21 09:40:31 +0000
+++ drizzled/statement/flush.cc	2010-02-11 03:29:52 +0000
@@ -42,7 +42,7 @@
      *
      * Presumably, RESET and binlog writing doesn't require synchronization
      */
-    write_bin_log(session, session->query, session->query_length);
+    write_bin_log(session, session->query.c_str());
     session->my_ok();
   }
 

=== modified file 'drizzled/statement/insert.cc'
--- drizzled/statement/insert.cc	2009-12-21 09:40:31 +0000
+++ drizzled/statement/insert.cc	2010-02-11 20:01:37 +0000
@@ -45,7 +45,7 @@
     return true;
   }
 
-  DRIZZLE_INSERT_START(session->query);
+  DRIZZLE_INSERT_START(session->query.c_str());
 
   bool res= mysql_insert(session,
                          all_tables,

=== modified file 'drizzled/statement/insert_select.cc'
--- drizzled/statement/insert_select.cc	2009-12-21 09:40:31 +0000
+++ drizzled/statement/insert_select.cc	2010-02-11 20:01:37 +0000
@@ -56,7 +56,7 @@
 
   if (! (res= session->openTablesLock(all_tables)))
   {
-    DRIZZLE_INSERT_SELECT_START(session->query);
+    DRIZZLE_INSERT_SELECT_START(session->query.c_str());
     /* Skip first table, which is the table we are inserting in */
     TableList *second_table= first_table->next_local;
     select_lex->table_list.first= (unsigned char*) second_table;

=== modified file 'drizzled/statement/rename_table.cc'
--- drizzled/statement/rename_table.cc	2009-12-21 09:40:31 +0000
+++ drizzled/statement/rename_table.cc	2010-02-11 03:29:52 +0000
@@ -110,7 +110,7 @@
   /* Lets hope this doesn't fail as the result will be messy */
   if (! error)
   {
-    write_bin_log(session, session->query, session->query_length);
+    write_bin_log(session, session->query.c_str());
     session->my_ok();
   }
 

=== modified file 'plugin/innobase/dict/dict0dict.c'
--- plugin/innobase/dict/dict0dict.c	2010-02-04 08:14:46 +0000
+++ plugin/innobase/dict/dict0dict.c	2010-02-11 03:29:52 +0000
@@ -3750,7 +3750,7 @@
 
 	*constraints_to_drop = mem_heap_alloc(heap, 1000 * sizeof(char*));
 
-	str = dict_strip_comments(*(trx->mysql_query_str));
+	str = dict_strip_comments((trx->mysql_query_str));
 	ptr = str;
 
 	ut_ad(mutex_own(&(dict_sys->mutex)));

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2010-02-13 02:23:32 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2010-02-16 01:41:20 +0000
@@ -981,7 +981,7 @@
           session->getSecurityContext().getUser().c_str()
   );
   fprintf(f,
-          "\n%s", session->getQueryString()
+          "\n%s", session->getQueryString().c_str()
   );
 	putc('\n', f);
 }
@@ -1358,7 +1358,7 @@
 	trx = trx_allocate_for_mysql();
 
 	trx->mysql_thd = session;
-	trx->mysql_query_str = session_query(session);
+	trx->mysql_query_str = session->query.c_str();
 
 	innobase_trx_init(session, trx);
 
@@ -5803,9 +5803,9 @@
 		}
 	}
 
-	if (*trx->mysql_query_str) {
+	if (trx->mysql_query_str) {
 		error = row_table_add_foreign_constraints(trx,
-			*trx->mysql_query_str, norm_name,
+			trx->mysql_query_str, norm_name,
 			lex_identified_temp_table);
 
 		error = convert_error_code_to_mysql(error, iflags, NULL);

=== modified file 'plugin/innobase/handler/ha_innodb.h'
--- plugin/innobase/handler/ha_innodb.h	2010-02-04 08:14:46 +0000
+++ plugin/innobase/handler/ha_innodb.h	2010-02-11 03:29:52 +0000
@@ -188,7 +188,6 @@
 
 
 extern "C" {
-char **session_query(Session *session);
 
 /** Get the file name of the MySQL binlog.
  * @return the name of the binlog file

=== modified file 'plugin/innobase/include/trx0trx.h'
--- plugin/innobase/include/trx0trx.h	2009-08-12 06:25:19 +0000
+++ plugin/innobase/include/trx0trx.h	2010-02-11 03:29:52 +0000
@@ -544,7 +544,7 @@
 	/*------------------------------*/
 	void*		mysql_thd;	/*!< MySQL thread handle corresponding
 					to this trx, or NULL */
-	char**		mysql_query_str;/* pointer to the field in mysqld_thd
+	const char*	mysql_query_str;/* pointer to the field in mysqld_thd
 					which contains the pointer to the
 					current SQL query string */
 	const char*	mysql_log_file_name;

=== modified file 'plugin/innobase/trx/trx0i_s.c'
--- plugin/innobase/trx/trx0i_s.c	2009-08-17 18:17:53 +0000
+++ plugin/innobase/trx/trx0i_s.c	2010-02-11 03:29:52 +0000
@@ -437,14 +437,14 @@
 		row->trx_mysql_thread_id = 0;
 	}
 
-	if (trx->mysql_query_str != NULL && *trx->mysql_query_str != NULL) {
+	if (trx->mysql_query_str != NULL) {
 
-		if (strlen(*trx->mysql_query_str)
+		if (strlen(trx->mysql_query_str)
 		    > TRX_I_S_TRX_QUERY_MAX_LEN) {
 
 			char	query[TRX_I_S_TRX_QUERY_MAX_LEN + 1];
 
-			memcpy(query, *trx->mysql_query_str,
+			memcpy(query, trx->mysql_query_str,
 			       TRX_I_S_TRX_QUERY_MAX_LEN);
 			query[TRX_I_S_TRX_QUERY_MAX_LEN] = '\0';
 
@@ -455,7 +455,7 @@
 		} else {
 
 			row->trx_query = ha_storage_put_str_memlim(
-				cache->storage, *trx->mysql_query_str,
+				cache->storage, trx->mysql_query_str,
 				MAX_ALLOWED_FOR_STORAGE(cache));
 		}
 

=== modified file 'plugin/logging_query/logging_query.cc'
--- plugin/logging_query/logging_query.cc	2010-01-13 08:18:49 +0000
+++ plugin/logging_query/logging_query.cc	2010-02-11 03:29:52 +0000
@@ -276,7 +276,7 @@
     if (re)
     {
       int this_pcre_rc;
-      this_pcre_rc = pcre_exec(re, pe, session->query, session->query_length, 0, 0, NULL, 0);
+      this_pcre_rc = pcre_exec(re, pe, session->query.c_str(), session->query.length(), 0, 0, NULL, 0);
       if (this_pcre_rc < 0)
         return false;
     }
@@ -298,7 +298,7 @@
                // dont need to quote the db name, always CSV safe
                (int)session->db.length(), dbs,
                // do need to quote the query
-               quotify((unsigned char *)session->getQueryString(),
+               quotify((unsigned char *)session->getQueryString().c_str(),
                        session->getQueryLength(), qs, sizeof(qs)),
                // command_name is defined in drizzled/sql_parse.cc
                // dont need to quote the command name, always CSV safe

=== modified file 'plugin/logging_syslog/logging_syslog.cc'
--- plugin/logging_syslog/logging_syslog.cc	2010-01-13 08:18:49 +0000
+++ plugin/logging_syslog/logging_syslog.cc	2010-02-11 03:29:52 +0000
@@ -145,7 +145,7 @@
   
     const char *dbs= session->db.empty() ? "" : session->db.c_str();
   
-    const char *qys= (session->getQueryString()) ? session->getQueryString() : "";
+    const char *qys= (! session->getQueryString().empty()) ? session->getQueryString().c_str() : "";
     int qyl= 0;
     if (qys)
       qyl= session->getQueryLength();

